@@ -1,8 +1,4 @@
 """
-Filename: quad.py
-Authors: Chase Coleman, Spencer Lyon
-Date: 2014-07-01
-
 Defining various quadrature routines.
 
 Based on the quadrature routines found in the CompEcon toolbox by
@@ -14,22 +10,34 @@ Miranda, Mario J, and Paul L Fackler. Applied Computational Economics
 and Finance, MIT Press, 2002.
 
 """
-from __future__ import division
-
 import math
 import numpy as np
 import scipy.linalg as la
-from scipy.special import gammaln
-import sympy as sym
+from numba import jit, vectorize
 from .ce_util import ckron, gridmake
+from .util import check_random_state
 
 __all__ = ['qnwcheb', 'qnwequi', 'qnwlege', 'qnwnorm', 'qnwlogn',
            'qnwsimp', 'qnwtrap', 'qnwunif', 'quadrect', 'qnwbeta',
            'qnwgamma']
 
-## ------------------ ##
-#- Exported Functions -#
-## ------------------ ##
+
+@vectorize(nopython=True)
+def gammaln(x):
+    return math.lgamma(x)
+
+
+@vectorize(nopython=True)
+def fix(x):
+    if x < 0:
+        return math.ceil(x)
+    else:
+        return math.floor(x)
+
+
+# ------------------ #
+# Exported Functions #
+# ------------------ #
 
 
 def qnwcheb(n, a=1, b=1):
@@ -73,7 +81,7 @@ def qnwcheb(n, a=1, b=1):
     return _make_multidim_func(_qnwcheb1, n, a, b)
 
 
-def qnwequi(n, a, b, kind="N", equidist_pp=None):
+def qnwequi(n, a, b, kind="N", equidist_pp=None, random_state=None):
     """
     Generates equidistributed sequences with property that averages
     value of integrable function evaluated over the sequence converges
@@ -105,6 +113,12 @@ def qnwequi(n, a, b, kind="N", equidist_pp=None):
     equidist_pp : array_like, optional(default=None)
         TODO: I don't know what this does
 
+    random_state : int or np.random.RandomState, optional
+        Random seed (integer) or np.random.RandomState instance to set
+        the initial state of the random number generator for
+        reproducibility. If None, a randomly initialized RandomState is
+        used.
+
     Returns
     -------
     nodes : np.ndarray(dtype=float)
@@ -124,7 +138,10 @@ def qnwequi(n, a, b, kind="N", equidist_pp=None):
     Economics and Finance, MIT Press, 2002.
 
     """
+    random_state = check_random_state(random_state)
+
     if equidist_pp is None:
+        import sympy as sym
         equidist_pp = np.sqrt(np.array(list(sym.primerange(0, 7920))))
 
     n, a, b = list(map(np.atleast_1d, list(map(np.asarray, [n, a, b]))))
@@ -138,22 +155,23 @@ def qnwequi(n, a, b, kind="N", equidist_pp=None):
     if b.size == 1:
         b = np.repeat(b, d)
 
-    i = np.arange(1, n + 1)
+    # Specify `dtype=np.int64` to avoid overflow on Windows
+    i = np.arange(1, n + 1, dtype=np.int64)
 
     if kind.upper() == "N":  # Neiderreiter
         j = 2.0 ** (np.arange(1, d+1) / (d+1))
         nodes = np.outer(i, j)
-        nodes = (nodes - np.fix(nodes)).squeeze()
+        nodes = (nodes - fix(nodes)).squeeze()
     elif kind.upper() == "W":  # Weyl
         j = equidist_pp[:d]
         nodes = np.outer(i, j)
-        nodes = (nodes - np.fix(nodes)).squeeze()
+        nodes = (nodes - fix(nodes)).squeeze()
     elif kind.upper() == "H":  # Haber
         j = equidist_pp[:d]
         nodes = np.outer(i * (i+1) / 2, j)
-        nodes = (nodes - np.fix(nodes)).squeeze()
+        nodes = (nodes - fix(nodes)).squeeze()
     elif kind.upper() == "R":  # pseudo-random
-        nodes = np.random.rand(n, d).squeeze()
+        nodes = random_state.rand(n, d).squeeze()
     else:
         raise ValueError("Unknown sequence requested")
 
@@ -243,21 +261,21 @@ def qnwnorm(n, mu=None, sig2=None, usesqrtm=False):
     Economics and Finance, MIT Press, 2002.
 
     """
-    n = np.asarray(n)
+    n = np.atleast_1d(n)
     d = n.size
 
     if mu is None:
         mu = np.zeros(d)
     else:
-        mu = np.asarray(mu)
+        mu = np.atleast_1d(mu)
 
     if sig2 is None:
         sig2 = np.eye(d)
     else:
-        sig2 = np.asarray(sig2).reshape(d, d)
+        sig2 = np.atleast_1d(sig2).reshape(d, d)
 
     if all([x.size == 1 for x in [n, mu, sig2]]):
-        nodes, weights = _qnwnorm1(n)
+        nodes, weights = _qnwnorm1(n[0])
     else:
         nodes = []
         weights = []
@@ -464,7 +482,7 @@ def quadrect(f, n, a, b, kind='lege', *args, **kwargs):
         that accepts as its first argument a matrix representing points
         along each dimension (each dimension is a column). Other
         arguments that need to be passed to the function are caught by
-        *args and **kwargs
+        `*args` and `**kwargs`
 
     n : int or array_like(float)
         A length-d iterable of the number of nodes in each dimension
@@ -564,7 +582,7 @@ def qnwbeta(n, a=1.0, b=1.0):
     return _make_multidim_func(_qnwbeta1, n, a, b)
 
 
-def qnwgamma(n, a=None):
+def qnwgamma(n, a=1.0, b=1.0, tol=3e-14):
     """
     Computes nodes and weights for gamma distribution
 
@@ -573,14 +591,14 @@ def qnwgamma(n, a=None):
     n : int or array_like(float)
         A length-d iterable of the number of nodes in each dimension
 
-    mu : scalar or array_like(float), optional(default=zeros(d))
-        The means of each dimension of the random variable. If a scalar
-        is given, that constant is repeated d times, where d is the
-        number of dimensions
+    a : scalar or array_like(float) : optional(default=ones(d))
+        Shape parameter of the gamma distribution parameter. Must be positive
 
-    sig2 : array_like(float), optional(default=eye(d))
-        A d x d array representing the variance-covariance matrix of the
-        multivariate normal distribution.
+    b : scalar or array_like(float) : optional(default=ones(d))
+        Scale parameter of the gamma distribution parameter. Must be positive
+
+    tol : scalar or array_like(float) : optional(default=ones(d) * 3e-14)
+        Tolerance parameter for newton iterations for each node
 
     Returns
     -------
@@ -601,11 +619,11 @@ def qnwgamma(n, a=None):
     Economics and Finance, MIT Press, 2002.
 
     """
-    return _make_multidim_func(_qnwgamma1, n, a)
+    return _make_multidim_func(_qnwgamma1, n, a, b, tol)
 
-## ------------------ ##
-#- Internal Functions -#
-## ------------------ ##
+# ------------------ #
+# Internal Functions #
+# ------------------ #
 
 
 def _make_multidim_func(one_d_func, n, *args):
@@ -638,12 +656,12 @@ def _make_multidim_func(one_d_func, n, *args):
 
 
     """
-    args = list(args)
-    n = np.asarray(n)
-    args = list(map(np.asarray, args))
+    _args = list(args)
+    n = np.atleast_1d(n)
+    args = list(map(np.atleast_1d, _args))
 
     if all([x.size == 1 for x in [n] + args]):
-        return one_d_func(n, *args)
+        return one_d_func(n[0], *_args)
 
     d = n.size
 
@@ -666,6 +684,7 @@ def _make_multidim_func(one_d_func, n, *args):
     return nodes, weights
 
 
+@jit(nopython=True)
 def _qnwcheb1(n, a, b):
     """
     Compute univariate Guass-Checbychev quadrature nodes and weights
@@ -705,15 +724,16 @@ def _qnwcheb1(n, a, b):
     # Create temporary arrays to be used in computing weights
     t1 = np.arange(1, n+1) - 0.5
     t2 = np.arange(0.0, n, 2)
-    t3 = np.concatenate([np.array([1.0]),
-                        -2.0/(np.arange(1.0, n-1, 2)*np.arange(3.0, n+1, 2))])
+    t3 = np.concatenate((np.array([1.0]),
+                        -2.0/(np.arange(1.0, n-1, 2)*np.arange(3.0, n+1, 2))))
 
     # compute weights and return
-    weights = ((b-a)/n)*np.cos(np.pi/n*np.outer(t1, t2)).dot(t3)
+    weights = ((b-a)/n)*np.cos(np.pi/n*np.outer(t1, t2)) @ t3
 
     return nodes, weights
 
 
+@jit(nopython=True)
 def _qnwlege1(n, a, b):
     """
     Compute univariate Guass-Legendre quadrature nodes and weights
@@ -750,28 +770,31 @@ def _qnwlege1(n, a, b):
     """
     # import ipdb; ipdb.set_trace()
     maxit = 100
-    m = np.fix((n + 1) / 2.0).astype(int)
+    m = int(fix((n + 1) / 2.0))
     xm = 0.5 * (b + a)
     xl = 0.5 * (b - a)
     nodes = np.zeros(n)
 
     weights = nodes.copy()
-    i = np.arange(m, dtype='int')
+    i = np.arange(m)
 
     z = np.cos(np.pi * ((i + 1.0) - 0.25) / (n + 0.5))
 
     for its in range(maxit):
-        p1 = 1.0
-        p2 = 0.0
+        p1 = np.ones_like(z)
+        p2 = np.zeros_like(z)
         for j in range(1, n+1):
             p3 = p2
             p2 = p1
             p1 = ((2 * j - 1) * z * p2 - (j - 1) * p3) / j
 
-        pp = n * (z * p1 - p2)/(z * z - 1.0)
+        # https://github.com/QuantEcon/QuantEcon.py/issues/530
+        top = n * (z * p1 - p2)
+        bottom = z ** 2 - 1.0
+        pp = top / bottom
         z1 = z.copy()
         z = z1 - p1/pp
-        if all(np.abs(z - z1) < 1e-14):
+        if np.all(np.abs(z - z1) < 1e-14):
             break
 
     if its == maxit - 1:
@@ -780,12 +803,14 @@ def _qnwlege1(n, a, b):
     nodes[i] = xm - xl * z
     nodes[- i - 1] = xm + xl * z
 
-    weights[i] = 2 * xl / ((1 - z * z) * pp * pp)
+    # https://github.com/QuantEcon/QuantEcon.py/issues/530
+    weights[i] = 2 * xl / ((1 - z ** 2) * pp * pp)
     weights[- i - 1] = weights[i]
 
     return nodes, weights
 
 
+@jit(nopython=True)
 def _qnwnorm1(n):
     """
     Compute nodes and weights for quadrature of univariate standard
@@ -817,7 +842,7 @@ def _qnwnorm1(n):
     """
     maxit = 100
     pim4 = 1 / np.pi**(0.25)
-    m = np.fix((n + 1) / 2).astype(int)
+    m = int(fix((n + 1) / 2))
     nodes = np.zeros(n)
     weights = np.zeros(n)
 
@@ -864,6 +889,7 @@ def _qnwnorm1(n):
     return nodes, weights
 
 
+@jit(nopython=True)
 def _qnwsimp1(n, a, b):
     """
     Compute univariate Simpson quadrature nodes and weights
@@ -904,7 +930,7 @@ def _qnwsimp1(n, a, b):
 
     nodes = np.linspace(a, b, n)
     dx = nodes[1] - nodes[0]
-    weights = np.tile([2.0, 4.0], (n + 1.0) / 2.0)
+    weights = np.kron(np.ones((n+1) // 2), np.array([2.0, 4.0]))
     weights = weights[:n]
     weights[0] = weights[-1] = 1
     weights = (dx / 3.0) * weights
@@ -912,6 +938,7 @@ def _qnwsimp1(n, a, b):
     return nodes, weights
 
 
+@jit(nopython=True)
 def _qnwtrap1(n, a, b):
     """
     Compute univariate trapezoid rule quadrature nodes and weights
@@ -959,6 +986,7 @@ def _qnwtrap1(n, a, b):
     return nodes, weights
 
 
+@jit(nopython=True)
 def _qnwbeta1(n, a=1.0, b=1.0):
     """
     Computes nodes and weights for quadrature on the beta distribution.
@@ -1074,28 +1102,32 @@ def _qnwbeta1(n, a=1.0, b=1.0):
         weights[i] = temp/(pp*p2)
 
     nodes = (1-nodes)/2
-    weights = weights * math.exp(gammaln(a+n) + gammaln(b+n)
-                                 - gammaln(n+1) - gammaln(n+ab+1))
-    weights = weights / (2*math.exp(gammaln(a+1) + gammaln(b+1)
-                         - gammaln(ab+2)))
+    weights = weights * math.exp(gammaln(a+n) + gammaln(b+n) -
+                                 gammaln(n+1) - gammaln(n+ab+1))
+    weights = weights / (2*math.exp(gammaln(a+1) + gammaln(b+1) -
+                         gammaln(ab+2)))
 
     return nodes, weights
 
 
-def _qnwgamma1(n, a=None):
+@jit(nopython=True)
+def _qnwgamma1(n, a=1.0, b=1.0, tol=3e-14):
     """
-    Insert docs.  Default is a=0
-
-    NOTE: For now I am just following compecon; would be much better to
-    find a different way since I don't know what they are doing.
+    1d quadrature weights and nodes for Gamma distributed random variable
 
     Parameters
     ----------
     n : scalar : int
         The number of quadrature points
 
-    a : scalar : float
-        Gamma distribution parameter
+    a : scalar : float, optional(default=1.0)
+        Shape parameter of the gamma distribution parameter. Must be positive
+
+    b : scalar : float, optional(default=1.0)
+        Scale parameter of the gamma distribution parameter. Must be positive
+
+    tol : scalar : float, optional(default=3e-14)
+        Tolerance parameter for newton iterations for each node
 
     Returns
     -------
@@ -1116,12 +1148,9 @@ def _qnwgamma1(n, a=None):
     Economics and Finance, MIT Press, 2002.
 
     """
-    if a is None:
-        a = 0
-    else:
-        a -= 1
+    a -= 1
 
-    maxit = 10
+    maxit = 25
 
     factor = -math.exp(gammaln(a+n) - gammaln(n) - gammaln(a+1))
     nodes = np.zeros(n)
@@ -1142,10 +1171,11 @@ def _qnwgamma1(n, a=None):
         # root finding iterations
         its = 0
         z1 = -10000
-        while abs(z - z1) > 1e-10 and its < maxit:
+        while abs(z - z1) > tol and its < maxit:
             p1 = 1.0
             p2 = 0.0
             for j in range(1, n+1):
+                # Recurrance relation for Laguerre polynomials
                 p3 = p2
                 p2 = p1
                 p1 = ((2*j - 1 + a - z)*p2 - (j - 1 + a)*p3) / j
@@ -1161,4 +1191,4 @@ def _qnwgamma1(n, a=None):
         nodes[i] = z
         weights[i] = factor / (pp*n*p2)
 
-    return nodes, weights
+    return nodes*b, weights
