@@ -1,8 +1,4 @@
 """
-Filename: quadsums.py
-
-Authors: Thomas Sargent,  John Stachurski
-
 This module provides functions to compute quadratic sums of the form described
 in the docstrings.
 
@@ -10,8 +6,8 @@ in the docstrings.
 
 
 import numpy as np
-from numpy import sqrt, dot
 import scipy.linalg
+from .matrix_eqn import solve_discrete_lyapunov
 
 
 def var_quadratic_sum(A, C, H, beta, x0):
@@ -20,10 +16,10 @@ def var_quadratic_sum(A, C, H, beta, x0):
 
     .. math::
 
-        q(x_0) = E \sum_{t=0}^{\infty} \beta^t x_t' H x_t
+        q(x_0) = \mathbb{E} \Big[ \sum_{t=0}^{\infty} \beta^t x_t' H x_t \Big]
 
-    Here {x_t} is the VAR process x_{t+1} = A x_t + C w_t with {w_t}
-    standard normal and x_0 the initial condition.
+    Here :math:`{x_t}` is the VAR process :math:`x_{t+1} = A x_t + C w_t`
+    with :math:`{x_t}` standard normal and :math:`x_0` the initial condition.
 
     Parameters
     ----------
@@ -42,13 +38,14 @@ def var_quadratic_sum(A, C, H, beta, x0):
     Returns
     -------
     q0: scalar(float)
-        Represents the value q(x_0)
+        Represents the value :math:`q(x_0)`
 
-    Remarks: The formula for computing q(x_0) is q(x_0) = x_0' Q x_0 + v
+    Remarks: The formula for computing :math:`q(x_0)` is
+    :math:`q(x_0) = x_0' Q x_0 + v`
     where
 
-        Q is the solution to Q = H + beta A' Q A and
-        v = \trace(C' Q C) \beta / (1 - \beta)
+        * :math:`Q` is the solution to :math:`Q = H + \beta A' Q A`, and
+        * :math:`v = \frac{trace(C' Q C) \beta}{(1 - \beta)}`
 
     """
     # == Make sure that A, C, H and x0 are array_like == #
@@ -56,10 +53,10 @@ def var_quadratic_sum(A, C, H, beta, x0):
     A, C, H = list(map(np.atleast_2d, (A, C, H)))
     x0 = np.atleast_1d(x0)
     # == Start computations == #
-    Q = scipy.linalg.solve_discrete_lyapunov(sqrt(beta) * A.T, H)
-    cq = dot(dot(C.T, Q), C)
+    Q = scipy.linalg.solve_discrete_lyapunov(np.sqrt(beta) * A.T, H)
+    cq = np.dot(np.dot(C.T, Q), C)
     v = np.trace(cq) * beta / (1 - beta)
-    q0 = dot(dot(x0.T, Q), x0) + v
+    q0 = np.dot(np.dot(x0.T, Q), x0) + v
 
     return q0
 
@@ -72,25 +69,19 @@ def m_quadratic_sum(A, B, max_it=50):
 
         V = \sum_{j=0}^{\infty} A^j B A^{j'}
 
-    V is computed by using a doubling algorithm. In particular, we
-    iterate to convergence on V_j with the following recursions for j =
-    1, 2,... starting from V_0 = B, a_0 = A:
-
-    .. math::
-
-        a_j = a_{j-1} a_{j-1}
-
-        V_j = V_{j-1} + a_{j-1} V_{j-1} a_{j-1}'
+    V is computed by solving the corresponding discrete lyapunov
+    equation using the doubling algorithm.  See the documentation of
+    `util.solve_discrete_lyapunov` for more information.
 
     Parameters
     ----------
     A : array_like(float, ndim=2)
         An n x n matrix as described above.  We assume in order for
-        convergence that the eigenvalues of A have moduli bounded by
+        convergence that the eigenvalues of :math:`A` have moduli bounded by
         unity
     B : array_like(float, ndim=2)
         An n x n matrix as described above.  We assume in order for
-        convergence that the eigenvalues of A have moduli bounded by
+        convergence that the eigenvalues of :math:`A` have moduli bounded by
         unity
     max_it : scalar(int), optional(default=50)
         The maximum number of iterations
@@ -98,29 +89,10 @@ def m_quadratic_sum(A, B, max_it=50):
     Returns
     ========
     gamma1: array_like(float, ndim=2)
-        Represents the value V
+        Represents the value :math:`V`
 
     """
-    A, B = list(map(np.atleast_2d, [A, B]))
-    alpha0 = A
-    gamma0 = B
 
-    diff = 5
-    n_its = 1
-
-    while diff > 1e-15:
-
-        alpha1 = alpha0.dot(alpha0)
-        gamma1 = gamma0 + np.dot(alpha0.dot(gamma0), alpha0.T)
-
-        diff = np.max(np.abs(gamma1 - gamma0))
-        alpha0 = alpha1
-        gamma0 = gamma1
-
-        n_its += 1
-
-        if n_its > max_it:
-            raise ValueError('Exceeded maximum iterations of %i.' % (max_it) +
-                             ' Check your input matrices')
+    gamma1 = solve_discrete_lyapunov(A, B, max_it)
 
     return gamma1
